@@ -5,9 +5,11 @@
  */
 
 #include "controllermanager.h"
-#include "libcec/ceccontroller.h"
 #include "evdev/evdevcontroller.h"
 
+#ifdef HAS_LIBCEC
+#include "libcec/ceccontroller.h"
+#endif
 #ifdef HAS_XWIIMOTE
 # include "wiimote/wiimotecontroller.h"
 #endif // HAS_XWIIMOTE
@@ -15,6 +17,7 @@
 #include <QGuiApplication>
 #include <QDebug>
 #include <QDBusConnection>
+#include <KLocalizedString>
 
 #include <fcntl.h>
 #include <unistd.h>
@@ -22,11 +25,14 @@
 int main(int argc, char *argv[])
 {
     QGuiApplication app(argc, argv);
+    KLocalizedString::setApplicationDomain("plasma-remotecontrollers");
 
     new EvdevController();
 
+#ifdef HAS_LIBCEC
     CECController* ct = new CECController();
     ct->start();
+#endif
     
 #ifdef HAS_XWIIMOTE
     new WiimoteController();
